Crate clmm_bindings

Crate clmm_bindings 

Structs

ClpVault
SwapCache
SwapEventCache
TokenRatio
VaultPosition
VaultRatioCache

Enums

CacheState
SourceState
StrategyType

Constants

MAX_ACTIVE_POSITIONS
The maximum number of active positions the CLP Vault could have on the underlying valut at a single time.
MAX_POSITIONS
The maximum number of positions a vault could have. This dictates the space required for the CLP Vault. There is a separate constant for limiting active positions. These are separate because the max active positions will start at 1 for v1.0.0 of the protocol.

Statics

ID
The static program ID

Functions

check_id
Confirms that a given pubkey is equivalent to the program ID
id
Returns the program ID