pub struct TokenRatio {
pub token_a: u64,
pub token_b: u64,
}Fields
token_a: u64The amount of token a required for the initial deposit
token_b: u64The amount of token b required for the initial deposit