Structs
Enums
Constants
- MAX_
ACTIVE_ POSITIONS - The maximum number of active positions the CLP Vault could have on the underlying valut at a single time.
- MAX_
POSITIONS - The maximum number of positions a vault could have. This dictates the space required for the CLP Vault. There is a separate constant for limiting active positions. These are separate because the max active positions will start at 1 for v1.0.0 of the protocol.
Statics
- ID
- The static program ID